@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -65,27 +65,27 @@ import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.i18n.FolderStrings;
 import com.openexchange.groupware.settings.SettingException;
 import com.openexchange.i18n.tools.StringHelper;
-import com.openexchange.login.LoginResult;
 import com.openexchange.login.LoginHandlerService;
+import com.openexchange.login.LoginResult;
 import com.openexchange.preferences.ServerUserSetting;
 import com.openexchange.server.ServiceException;
 import com.openexchange.server.impl.OCLPermission;
 import com.openexchange.session.Session;
 import com.openexchange.tools.oxfolder.OXFolderAccess;
 import com.openexchange.tools.oxfolder.OXFolderException;
+import com.openexchange.tools.oxfolder.OXFolderException.FolderCode;
 import com.openexchange.tools.oxfolder.OXFolderManager;
 import com.openexchange.tools.oxfolder.OXFolderSQL;
-import com.openexchange.tools.oxfolder.OXFolderException.FolderCode;
 
 /**
  * {@link ContactCollectorFolderCreator}
- * 
+ *
  * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class ContactCollectorFolderCreator implements LoginHandlerService {
 
-    private static final Log LOG = LogFactory.getLog(ContactCollectorFolderCreator.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ContactCollectorFolderCreator.class));
 
     /**
      * Initializes a new {@link ContactCollectorFolderCreator}.
@@ -95,36 +95,37 @@ public class ContactCollectorFolderCreator implements LoginHandlerService {
     }
 
     public void handleLogin(final LoginResult login) throws LoginException {
-        int cid = login.getSession().getContextId();
+        final int cid = login.getSession().getContextId();
         DatabaseService databaseService = null;
         Connection con = null;
         try {
             databaseService = CCServiceRegistry.getInstance().getService(DatabaseService.class, true);
             con = databaseService.getWritable(cid);
-            String folderName = new StringHelper(login.getUser().getLocale()).getString(FolderStrings.DEFAULT_CONTACT_COLLECT_FOLDER_NAME);
+            final String folderName = StringHelper.valueOf(login.getUser().getLocale()).getString(FolderStrings.DEFAULT_CONTACT_COLLECT_FOLDER_NAME);
             create(login.getSession(), login.getContext(), folderName, con);
-        } catch (ServiceException e) {
+        } catch (final ServiceException e) {
             throw new LoginException(e);
-        } catch (DBPoolingException e) {
+        } catch (final DBPoolingException e) {
             throw new LoginException(e);
-        } catch (SettingException e) {
+        } catch (final SettingException e) {
             throw new LoginException(e);
-        } catch (OXException e) {
+        } catch (final OXException e) {
             throw new LoginException(e);
-        } catch (SQLException e) {
+        } catch (final SQLException e) {
             throw new LoginException(new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage()));
-        } catch (AbstractOXException e) {
+        } catch (final AbstractOXException e) {
             throw new LoginException(e);
         } finally {
-            if (databaseService != null)
+            if (databaseService != null) {
                 databaseService.backWritable(cid, con);
+            }
         }
     }
-    
-    public void create(Session session, Context ctx, String folderName, Connection con) throws AbstractOXException, SQLException {
+
+    public void create(final Session session, final Context ctx, final String folderName, final Connection con) throws AbstractOXException, SQLException {
         final int cid = session.getContextId();
         final int userId = session.getUserId();
-    
+
         final ServerUserSetting serverUserSetting = ServerUserSetting.getInstance(con);
 
         final Integer folderId = serverUserSetting.getContactCollectionFolder(cid, userId);
@@ -137,15 +138,13 @@ public class ContactCollectorFolderCreator implements LoginHandlerService {
         }
         if (!serverUserSetting.isContactCollectionEnabled(cid, userId).booleanValue() && isConfigured(serverUserSetting, cid, userId)) {
             /*
-             * Explicitly turned off
+             * Both - collect-on-mail-access and collect-on-mail-transport - disabled
              */
             return;
         }
-        /*
+        /*-
          * Should collect, or not explicitly set, so create folder
-         */
-
-        /*
+         * 
          * Create folder
          */
         int collectFolderID = 0;
@@ -156,7 +155,7 @@ public class ContactCollectorFolderCreator implements LoginHandlerService {
                     createNewContactFolder(userId, folderName, parent),
                     true,
                     System.currentTimeMillis()).getObjectID();
-        } catch (OXFolderException folderException) {
+        } catch (final OXFolderException folderException) {
             if (folderException.getDetailNumber() == OXFolderException.FolderCode.NO_DUPLICATE_FOLDER.getNumber()) {
                 LOG.info(new StringBuilder("Found Folder with name of contact collect folder. Guess this is the dedicated folder."));
                 collectFolderID = OXFolderSQL.lookUpFolder(parent, folderName, FolderObject.CONTACT, con, ctx);
@@ -166,15 +165,15 @@ public class ContactCollectorFolderCreator implements LoginHandlerService {
          * Remember folder ID
          */
         serverUserSetting.setContactCollectionFolder(cid, userId, Integer.valueOf(collectFolderID));
-        serverUserSetting.setContactCollectOnMailAccess(cid, userId, true);
-        serverUserSetting.setContactCollectOnMailTransport(cid, userId, true);
+        serverUserSetting.setContactCollectOnMailAccess(cid, userId, serverUserSetting.isContactCollectOnMailAccess(cid, userId).booleanValue());
+        serverUserSetting.setContactCollectOnMailTransport(cid, userId, serverUserSetting.isContactCollectOnMailTransport(cid, userId).booleanValue());
         if (LOG.isInfoEnabled()) {
             LOG.info(new StringBuilder("Contact collector folder (id=").append(collectFolderID).append(
                 ") successfully created for user ").append(userId).append(" in context ").append(cid));
         }
     }
-    
-    private boolean isConfigured(ServerUserSetting setting, int cid, int userId) throws SettingException {
+
+    private boolean isConfigured(final ServerUserSetting setting, final int cid, final int userId) throws SettingException {
         return setting.getContactCollectionFolder(cid, userId) != null;
     }
 
