@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,30 +52,23 @@ package com.openexchange.contactcollector.internal;
 import java.sql.Connection;
 import java.sql.SQLException;
 import java.util.List;
-import java.util.Set;
-import java.util.concurrent.Future;
 import javax.mail.internet.InternetAddress;
-import com.openexchange.concurrent.TimeoutConcurrentMap;
 import com.openexchange.contactcollector.ContactCollectorService;
 import com.openexchange.contactcollector.folder.ContactCollectorFolderCreator;
-import com.openexchange.contactcollector.osgi.CCServiceRegistry;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.server.ServiceException;
 import com.openexchange.session.Session;
-import com.openexchange.threadpool.ThreadPoolService;
-import com.openexchange.threadpool.ThreadPools;
-import com.openexchange.threadpool.behavior.CallerRunsBehavior;
 
 /**
  * {@link ContactCollectorServiceImpl}
- * 
+ *
  * @author <a href="mailto:martin.herfurth@open-xchange.org">Martin Herfurth</a>
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class ContactCollectorServiceImpl implements ContactCollectorService {
 
-    private TimeoutConcurrentMap<Integer, Future<Set<InternetAddress>>> aliasesMap;
+    private MemorizerWorker worker;
 
     /**
      * Initializes a new {@link ContactCollectorServiceImpl}.
@@ -88,41 +81,43 @@ public class ContactCollectorServiceImpl implements ContactCollectorService {
         memorizeAddresses(addresses, session, true);
     }
 
-    public void memorizeAddresses(final List<InternetAddress> addresses, final Session session, boolean background) {
-        /*
-         * Delegate to thread pool if available
-         */
-        final ThreadPoolService threadPoolService = CCServiceRegistry.getInstance().getService(ThreadPoolService.class);
-        if (!background || null == threadPoolService) {
-            // Run in calling thread
-            new Memorizer(addresses, session, aliasesMap).run();
+    public void memorizeAddresses(final List<InternetAddress> addresses, final Session session, final boolean background) {
+        if (background) {
+            /*
+             * Submit
+             */
+            try {
+                worker.submit(new MemorizerTask(addresses, session));
+            } catch (final ServiceException e) {
+                /*
+                 * Thread pool service is missing. Run with this thread
+                 */
+                MemorizerWorker.handleTask(new MemorizerTask(addresses, session));
+            }
         } else {
-            threadPoolService.submit(
-                ThreadPools.task(new Memorizer(addresses, session, aliasesMap), "ContactCollector"),
-                CallerRunsBehavior.getInstance());
+            MemorizerWorker.handleTask(new MemorizerTask(addresses, session));
         }
     }
 
     /**
      * Starts this contact collector service implementation.
-     * 
+     *
      * @throws ServiceException If a needed service is missing
      */
     public void start() throws ServiceException {
-        aliasesMap = new TimeoutConcurrentMap<Integer, Future<Set<InternetAddress>>>(60, true);
+        AliasesProvider.getInstance().start();
+        worker = new MemorizerWorker();
     }
 
     /**
      * Stops this contact collector service implementation.
      */
     public void stop() {
-        if (null != aliasesMap) {
-            aliasesMap.dispose();
-            aliasesMap = null;
-        }
+        worker.close();
+        AliasesProvider.getInstance().stop();
     }
 
-    public void createCollectFolder(Session session, Context ctx, String folderName, Connection con) throws AbstractOXException, SQLException {
+    public void createCollectFolder(final Session session, final Context ctx, final String folderName, final Connection con) throws AbstractOXException, SQLException {
         new ContactCollectorFolderCreator().create(session, ctx, folderName, con);
     }
 
