@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -97,13 +97,13 @@ import com.openexchange.userconf.UserConfigurationService;
 
 /**
  * {@link Memorizer}
- * 
+ *
  * @author <a href="mailto:martin.herfurth@open-xchange.org">Martin Herfurth</a>
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class Memorizer implements Runnable {
 
-    private static final Log LOG = LogFactory.getLog(ServerUserSetting.class);
+    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ServerUserSetting.class));
 
     private static final boolean ALL_ALIASES = true;
 
@@ -119,7 +119,7 @@ public class Memorizer implements Runnable {
 
     /**
      * Initializes a new {@link Memorizer}.
-     * 
+     *
      * @param addresses The addresses to insert if not already present
      * @param session The associated session
      * @param aliasesMap The aliases map holding already determined aliases per context
@@ -196,8 +196,13 @@ public class Memorizer implements Runnable {
         }
     }
 
+    private static final int[] COLUMNS = { DataObject.OBJECT_ID, FolderChildObject.FOLDER_ID, DataObject.LAST_MODIFIED, Contact.USE_COUNT };
+
     private int memorizeContact(final InternetAddress address, final Context ctx, final UserConfiguration userConfig) throws AbstractOXException {
-        Contact contact;
+        /*
+         * Convert email address to a contact
+         */
+        final Contact contact;
         try {
             contact = transformInternetAddress(address);
         } catch (final ParseException e) {
@@ -209,28 +214,33 @@ public class Memorizer implements Runnable {
             LOG.warn(e.getMessage(), e);
             return -1;
         }
+        /*
+         * Check if such a contact already exists
+         */
         final ContactInterface contactInterface =
             CCServiceRegistry.getInstance().getService(ContactInterfaceDiscoveryService.class).getContactInterfaceProvider(
                 contact.getParentFolderID(),
                 ctx.getContextId()).newContactInterface(session);
-        Contact foundContact = null;
+        final Contact foundContact;
         {
             final ContactSearchObject searchObject = new ContactSearchObject();
             searchObject.setEmailAutoComplete(true);
             searchObject.setDynamicSearchField(new int[] { Contact.EMAIL1, Contact.EMAIL2, Contact.EMAIL3, });
             searchObject.setDynamicSearchFieldValue(new String[] { contact.getEmail1(), contact.getEmail1(), contact.getEmail1() });
-            final int[] columns =
-                new int[] { DataObject.OBJECT_ID, FolderChildObject.FOLDER_ID, DataObject.LAST_MODIFIED, Contact.USE_COUNT };
-            final SearchIterator<Contact> iterator = contactInterface.getContactsByExtendedSearch(searchObject, 0, null, columns);
+            final SearchIterator<Contact> iterator = contactInterface.getContactsByExtendedSearch(searchObject, 0, null, null, COLUMNS);
             try {
                 if (iterator.hasNext()) {
                     foundContact = iterator.next();
+                } else {
+                    foundContact = null;
                 }
             } finally {
                 iterator.close();
             }
         }
-
+        /*
+         * Either create contact or increment its use count
+         */
         final int retval;
         if (null == foundContact) {
             final OXFolderAccess folderAccess = new OXFolderAccess(ctx);
@@ -263,7 +273,7 @@ public class Memorizer implements Runnable {
 
     /**
      * Gets the aliases of a specified user.
-     * 
+     *
      * @param user The user whose aliases shall be returned
      * @return The aliases of a specified user
      */
@@ -273,12 +283,12 @@ public class Memorizer implements Runnable {
             return Collections.emptySet();
         }
         final Set<InternetAddress> set = new HashSet<InternetAddress>(aliases.length);
-        for (int i = 0; i < aliases.length; i++) {
+        for (final String aliase : aliases) {
             try {
-                set.add(new QuotedInternetAddress(aliases[i], false));
+                set.add(new QuotedInternetAddress(aliase, false));
             } catch (final AddressException e) {
                 if (LOG.isDebugEnabled()) {
-                    LOG.debug(MessageFormat.format("Alias could not be parsed to an internet address: {0}", aliases[i]), e);
+                    LOG.debug(MessageFormat.format("Alias could not be parsed to an internet address: {0}", aliase), e);
                 }
             }
         }
@@ -335,7 +345,7 @@ public class Memorizer implements Runnable {
      * If the charset-conversion fails for any sequence, an {@link UnsupportedEncodingException} is thrown.
      * <p>
      * If the String is not a RFC 2047 style encoded value, it is returned as-is
-     * 
+     *
      * @param value The possibly encoded value
      * @return The possibly decoded value
      * @throws UnsupportedEncodingException If an unsupported charset encoding occurs
@@ -363,7 +373,7 @@ public class Memorizer implements Runnable {
 
     /**
      * Gets all aliases of all users of specified context.
-     * 
+     *
      * @param context The context
      * @param userService The user service
      * @return All aliases
@@ -379,8 +389,8 @@ public class Memorizer implements Runnable {
                     // All context-known users' aliases
                     final int[] allUserIDs = userService.listAllUser(context);
                     final Set<InternetAddress> aliases = new HashSet<InternetAddress>(allUserIDs.length * 8);
-                    for (int i = 0; i < allUserIDs.length; i++) {
-                        aliases.addAll(getAliases(userService.getUser(allUserIDs[i], context)));
+                    for (final int allUserID : allUserIDs) {
+                        aliases.addAll(getAliases(userService.getUser(allUserID, context)));
                     }
                     return aliases;
                 }
