@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -80,7 +80,7 @@ public class ContactCollectFolder implements PreferencesItemService {
             }
 
             public void getValue(final Session session, final Context ctx, final User user, final UserConfiguration userConfig, final Setting setting) throws SettingException {
-                final Integer value = ServerUserSetting.getDefaultInstance().getIContactCollectionFolder(ctx.getContextId(), user.getId());
+                final Integer value = ServerUserSetting.getInstance().getContactCollectionFolder(ctx.getContextId(), user.getId());
                 setting.setSingleValue(value);
             }
 
@@ -94,15 +94,17 @@ public class ContactCollectFolder implements PreferencesItemService {
 
             public void writeValue(final Session session, final Context ctx, final User user, final Setting setting) throws SettingException {
                 Integer value;
+                final Object singleValue = setting.getSingleValue();
                 try {
-                    if (setting.getSingleValue() == null)
+                    if (singleValue == null || "null".equalsIgnoreCase(singleValue.toString())) {
                         value = null;
-                    else
-                        value = new Integer(String.valueOf(setting.getSingleValue()));
+                    } else {
+                        value = Integer.valueOf(singleValue.toString());
+                    }
                 } catch (final NumberFormatException e) {
-                    throw new SettingException(Code.INVALID_VALUE, e, setting.getSingleValue(), "contactCollectFolder");
+                    throw new SettingException(Code.INVALID_VALUE, e, singleValue, "contactCollectFolder");
                 }
-                ServerUserSetting.getDefaultInstance().setIContactCollectionFolder(ctx.getContextId(), user.getId(), value);
+                ServerUserSetting.getInstance().setContactCollectionFolder(ctx.getContextId(), user.getId(), value);
             }
         };
     }
